package config

import (
	"flag"

	"git.paulbsd.com/paulbsd/coronafana/utils"
	"gopkg.in/ini.v1"
)

// GetConfig fetch configuration
func (config *Config) GetConfig() (err error) {
	var configfile string

	flag.Usage = utils.Usage

	flag.StringVar(&configfile, "configfile", "coronafana.ini", "config file to use with coronafana section")
	flag.Parse()

	cfg, err := ini.Load(configfile)
	if err != nil {
		return
	}

	coronafanasection := cfg.Section("coronafana")

	config.DbHostname = coronafanasection.Key("db_hostname").MustString("localhost")
	config.DbName = coronafanasection.Key("db_name").MustString("database")
	config.DbUsername = coronafanasection.Key("db_username").MustString("username")
	config.DbPassword = coronafanasection.Key("db_password").MustString("password")
	config.DbTable = coronafanasection.Key("db_table").MustString("corona")
	config.Corona.URL = coronafanasection.Key("corona_url").MustString("")

	config.DbSchemaGlobal = "CREATE TABLE IF NOT EXISTS coronaglobaldata 	(`id` int(8) NOT NULL AUTO_INCREMENT, `date` datetime NOT NULL, `infection` int(8) DEFAULT NULL, `deces` int(8) DEFAULT NULL, `guerisons` varchar(50) DEFAULT NULL, `tauxdeces` float(10) DEFAULT NULL, `tauxguerison` float(10) DEFAULT NULL, `tauxinfection` float(10) DEFAULT NULL, PRIMARY KEY (`id`), UNIQUE KEY `date` (`date`) USING BTREE) ENGINE=InnoDB DEFAULT CHARSET=utf8;"

	config.DbInsertGlobal = "INSERT INTO coronaglobaldata (date, infection, deces, guerisons, tauxdeces, tauxguerison, tauxinfection) VALUES (:date, :infection, :deces, :guerisons, :tauxdeces, :tauxguerison, :tauxinfection) ON DUPLICATE KEY UPDATE date=:date,infection=:infection, deces=:deces, guerisons=:guerisons, tauxdeces=:tauxdeces, tauxguerison=:tauxguerison, tauxinfection=:tauxinfection;"

	config.DbSchemaPays = "CREATE TABLE IF NOT EXISTS coronapaysdata (`id` int(8) NOT NULL AUTO_INCREMENT, `date` datetime NOT NULL, `pays` varchar(50) NOT NULL, `infection` int(8) DEFAULT NULL, `deces` int(8) DEFAULT NULL, `guerisons` varchar(50) DEFAULT NULL, `tauxdeces` float(10) DEFAULT NULL, `tauxguerison` float(10) DEFAULT NULL, `tauxinfection` float(10) DEFAULT NULL, PRIMARY KEY (`id`), UNIQUE KEY `date` (`date`,`pays`) USING BTREE) ENGINE=InnoDB DEFAULT CHARSET=utf8;"

	config.DbInsertPays = "INSERT INTO coronapaysdata (date, pays, infection, deces, guerisons, tauxdeces, tauxguerison, tauxinfection) VALUES (:date, :pays, :infection, :deces, :guerisons, :tauxdeces, :tauxguerison, :tauxinfection) ON DUPLICATE KEY UPDATE date=:date, pays=:pays,infection=:infection, deces=:deces, guerisons=:guerisons, tauxdeces=:tauxdeces, tauxguerison=:tauxguerison, tauxinfection=:tauxinfection;"

	return
}

// Config is the global config of g2g
type Config struct {
	DbHostname     string
	DbName         string
	DbUsername     string
	DbPassword     string
	DbTable        string
	DbSchemaGlobal string
	DbInsertGlobal string
	DbSchemaPays   string
	DbInsertPays   string
	Corona         struct {
		URL string
	}
}
