package coronafana

import (
	"encoding/json"
	"io/ioutil"
	"net/http"
	"strings"

	"git.paulbsd.com/paulbsd/coronafana/src/config"
	"github.com/jmoiron/sqlx"
)

// GetData fetch data from open data portal
func GetData(cfg config.Config) (cr Coronafana, err error) {
	var client http.Client

	resp, err := client.Get(cfg.Corona.URL)
	if err != nil {
		return
	}

	body, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return
	}
	defer resp.Body.Close()

	err = json.Unmarshal(body, &cr)
	if err != nil {
		return
	}

	return
}

// InsertGlobalData insert data to MySQL / MariaDB
func (cr Coronafana) InsertGlobalData(cfg config.Config, db sqlx.DB) (err error) {
	var tx *sqlx.Tx
	tx = db.MustBegin()
	txStmtglobal, err := tx.PrepareNamed(cfg.DbInsertGlobal)
	for _, dt := range cr.GlobalData {
		_, err = txStmtglobal.Exec(&dt)
		if err != nil {
			return
		}

	}
	err = tx.Commit()
	if err != nil {
		return
	}

	return
}

// InsertPaysData insert data to MySQL / MariaDB
func (cr Coronafana) InsertPaysData(cfg config.Config, db sqlx.DB) (err error) {
	var tx *sqlx.Tx
	tx = db.MustBegin()
	cr.ReplacePaysQuotes()
	txStmtpays, err := tx.PrepareNamed(cfg.DbInsertPays)
	for _, dt := range cr.PaysData {
		_, err = txStmtpays.Exec(&dt)
		if err != nil {
			return
		}
	}
	err = tx.Commit()
	if err != nil {
		return
	}
	return
}

// ReplacePaysQuotes escapes quotes in Pays names
func (cr Coronafana) ReplacePaysQuotes() (err error) {
	for _, pad := range cr.PaysData {
		pad.Pays = strings.Replace(pad.Pays, `'`, `\'`, -1)
	}
	return err
}

// Coronafana is the main struct
type Coronafana struct {
	Source      string `json:"Source"`
	Information string `json:"Information"`
	Utilisation string `json:"Utilisation"`
	GlobalData  []struct {
		Date          string  `json:"Date" gorm:"primary_key" db:"date"`
		Infection     int     `json:"Infection" db:"infection"`
		Deces         int     `json:"Deces" db:"deces"`
		Guerisons     int     `json:"Guerisons" db:"guerisons"`
		TauxDeces     float64 `json:"TauxDeces" db:"tauxdeces"`
		TauxGuerison  float64 `json:"TauxGuerison" db:"tauxguerison"`
		TauxInfection float64 `json:"TauxInfection" db:"tauxinfection"`
	} `json:"GlobalData"`
	PaysData []struct {
		Date          string  `json:"Date" gorm:"primary_key" db:"date"`
		Pays          string  `json:"Pays" db:"pays"`
		Infection     int     `json:"Infection" db:"infection"`
		Deces         int     `json:"Deces" db:"deces"`
		Guerisons     int     `json:"Guerisons" db:"guerisons"`
		TauxDeces     float64 `json:"TauxDeces" db:"tauxdeces"`
		TauxGuerison  float64 `json:"TauxGuerison" db:"tauxguerison"`
		TauxInfection float64 `json:"TauxInfection" db:"tauxinfection"`
	} `json:"PaysData"`
}
